==> base-domain-0.0.3-20170323.095851-111-sources.jar: com/thebeastshop/scm/po/CampaignSectionProduct.java <==
package com.thebeastshop.scm.po;

import pers.richard.ormybatis.domain.po.IdPo;

import java.math.BigDecimal;

/**
 * @author gongjun
 * @since 2016-11-30
 */
public class CampaignSectionProduct extends IdPo {

    private Long campaignId;					//活动编号
    private Long campaignSectionId;				//活动关联的优惠区间编号
    private Long additionalProductId;			//活动关联的额外商品编号
    private int additionalProductCount;			//额外商品数量
    private BigDecimal additionalProductPrice;	//额外商品的价格
    private double ranking;						//排序
    private Integer temp;						//是否为临时记录
    private String productCode;					//额外商品编码
    private String productName;					// 额外商品中文名

    public Long getCampaignId() {
        return campaignId;
    }

    public void setCampaignId(Long campaignId) {
        this.campaignId = campaignId;
    }

    public Long getCampaignSectionId() {
        return campaignSectionId;
    }

    public void setCampaignSectionId(Long campaignSectionId) {
        this.campaignSectionId = campaignSectionId;
    }

    public Long getAdditionalProductId() {
        return additionalProductId;
    }

    public void setAdditionalProductId(Long additionalProductId) {
        this.additionalProductId = additionalProductId;
    }

    public int getAdditionalProductCount() {
        return additionalProductCount;
    }

    public void setAdditionalProductCount(int additionalProductCount) {
        this.additionalProductCount = additionalProductCount;
    }

    public BigDecimal getAdditionalProductPrice() {
        return additionalProductPrice;
    }

    public void setAdditionalProductPrice(BigDecimal additionalProductPrice) {
        this.additionalProductPrice = additionalProductPrice;
    }

    public double getRanking() {
        return ranking;
    }

    public void setRanking(double ranking) {
        this.ranking = ranking;
    }

    public Integer getTemp() {
        return temp;
    }

    public void setTemp(Integer temp) {
        this.temp = temp;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

}

==> base-domain-1.0.0-sources.jar: com/thebeastshop/scm/po/CampaignSectionProduct.java <==
package com.thebeastshop.scm.po;

import pers.richard.ormybatis.domain.po.IdPo;

import java.math.BigDecimal;

/**
 * @author gongjun
 * @since 2016-11-30
 */
public class CampaignSectionProduct extends IdPo {

    private Long campaignId;					//活动编号
    private Long campaignSectionId;				//活动关联的优惠区间编号
    private Long additionalProductId;			//活动关联的额外商品编号
    private int additionalProductCount;			//额外商品数量
    private BigDecimal additionalProductPrice;	//额外商品的价格
    private double ranking;						//排序
    private Integer temp;						//是否为临时记录
    private String productCode;					//额外商品编码
    private String productName;					// 额外商品中文名
    private Integer limitCount;                 // 最大数量 换购每单限换购数 满赠每单赠数

    public Long getCampaignId() {
        return campaignId;
    }

    public void setCampaignId(Long campaignId) {
        this.campaignId = campaignId;
    }

    public Long getCampaignSectionId() {
        return campaignSectionId;
    }

    public void setCampaignSectionId(Long campaignSectionId) {
        this.campaignSectionId = campaignSectionId;
    }

    public Long getAdditionalProductId() {
        return additionalProductId;
    }

    public void setAdditionalProductId(Long additionalProductId) {
        this.additionalProductId = additionalProductId;
    }

    public int getAdditionalProductCount() {
        return additionalProductCount;
    }

    public void setAdditionalProductCount(int additionalProductCount) {
        this.additionalProductCount = additionalProductCount;
    }

    public BigDecimal getAdditionalProductPrice() {
        return additionalProductPrice;
    }

    public void setAdditionalProductPrice(BigDecimal additionalProductPrice) {
        this.additionalProductPrice = additionalProductPrice;
    }

    public double getRanking() {
        return ranking;
    }

    public void setRanking(double ranking) {
        this.ranking = ranking;
    }

    public Integer getTemp() {
        return temp;
    }

    public void setTemp(Integer temp) {
        this.temp = temp;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }

    public Integer getLimitCount() {
        return limitCount;
    }

    public void setLimitCount(Integer limitCount) {
        this.limitCount = limitCount;
    }
}
